@@ -16,9 +16,12 @@ class YsbException(Exception):
         self.error_code = error_code
         self.error_info = error_info
 
-    #类中调用方式如下
-    # try:
-    #     if "异常情况":
-    #         raise YsbException("-1", "失败", "1", "异常信息")
-    # except YsbException as e:
-    #     print("返回信息：", {"CODE": e.code, "MSG": e.msg, "ERROR_CODE": e.error_code, "ERROR_INFO": e.error_info})
+
+"""
+调用方法：
+    try:
+        if "异常情况":
+            raise YsbException("-1", "失败", "1", "异常信息")
+    except YsbException as e:
+        print("返回信息：", {"CODE": e.code, "MSG": e.msg, "ERROR_CODE": e.error_code, "ERROR_INFO": e.error_info})
+"""
